import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="swaglyrics",
    version="0.1.7",
    author="Aadi Bajpai",
    author_email="aadibajpai@gmail.com",
    description="Fetch the currently playing song from Spotify and display lyrics on cmd or in a browser tab.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/aadibajpai/SwagLyrics-For-Spotify",
    entry_points={'console_scripts': ['swaglyrics=swaglyrics.__main__:main']},
    packages=setuptools.find_packages(),
    license='MIT',
    include_package_data=True,
    install_requires=['flask', 'pywin32', 'requests', 'beautifulsoup4'],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows :: Windows 10",
    ),
)


import win32gui


def get_info_windows():
	windows = []

	# Older Spotify versions - simply FindWindow for "SpotifyMainWindow"
	windows.append(win32gui.GetWindowText(win32gui.FindWindow("SpotifyMainWindow", None)))

	# Newer Spotify versions - create an EnumHandler for EnumWindows and flood the list with Chrome_WidgetWin_0s
	def find_spotify_uwp(hwnd, windows):
		text = win32gui.GetWindowText(hwnd)
		if win32gui.GetClassName(hwnd) == "Chrome_WidgetWin_0" and len(text) > 0:
			windows.append(text)

	win32gui.EnumWindows(find_spotify_uwp, windows)

	while windows.count != 0:
		try:
			text = windows.pop()
		except:
			return None
		try:
			artist, track = text.split(" - ", 1)
			return artist, track
		except:
			pass


def artist():
	try:
		return get_info_windows()[0]
	except:
		return None


def song():
	try:
		return get_info_windows()[1]
	except:
		return None


import argparse
from swaglyrics.cli import lyrics, clear
import time
from swaglyrics import spotify
from swaglyrics.tab import app
import os


def main():
	parser = argparse.ArgumentParser(
		description="Get lyrics for currently playing song on Spotify. Either --tab or --cli is required.")

	parser.add_argument('-t', '--tab', action='store_true', help='Display lyrics in a browser tab.')
	parser.add_argument('-c', '--cli', action='store_true', help='Display lyrics in the command-line.')

	args = parser.parse_args()

	if args.tab:
		print('Firing up a browser tab!')
		app.template_folder = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'templates')
		app.static_folder = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'static')
		app.run()

	elif args.cli:
		song = spotify.song()  # get currently playing song
		artist = spotify.artist()  # get currently playing artist
		print(lyrics(song, artist))
		print('\n(Press Ctrl+C to quit)')
		while True:
			# refresh every 5s to check whether song changed
			# if changed, display the new lyrics
			try:
				if song == spotify.song() and artist == spotify.artist():
					time.sleep(5)
				else:
					song = spotify.song()
					artist = spotify.artist()
					if song and artist is not None:
						clear()
						print(lyrics(song, artist))
						print('\n(Press Ctrl+C to quit)')
			except KeyboardInterrupt:
				exit()

	else:
		parser.print_help()


if __name__ == '__main__':
	main()
